<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AudioItem</name>
    <message>
        <location filename="../../src/timeline/widgets/AudioItem.cc" line="+125"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
</context>
<context>
    <name>DateSeparator</name>
    <message>
        <location filename="../../src/timeline/TimelineView.cc" line="+54"/>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Yesterday</source>
        <translation>Gisteren</translation>
    </message>
</context>
<context>
    <name>EditModal</name>
    <message>
        <location filename="../../src/dialogs/RoomSettings.cpp" line="+34"/>
        <source>APPLY</source>
        <translation>TOEPASSEN</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Topic</source>
        <translation>Onderwerp</translation>
    </message>
</context>
<context>
    <name>FileItem</name>
    <message>
        <location filename="../../src/timeline/widgets/FileItem.cc" line="+111"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../../src/timeline/widgets/ImageItem.cc" line="+229"/>
        <source>Save image</source>
        <translation>Afbeelding opslaan</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <location filename="../../src/LoginPage.cc" line="+79"/>
        <source>Matrix ID</source>
        <translation>Matrix-id</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>e.g @joe:matrix.org</source>
        <translation>b.v @jan:matrix.org&lt;</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>LOGIN</source>
        <translation>INLOGGEN</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Empty password</source>
        <translation>Leeg wachtwoord</translation>
    </message>
</context>
<context>
    <name>MatrixClient</name>
    <message>
        <location filename="../../src/MatrixClient.cc" line="+164"/>
        <source>Wrong username or password</source>
        <translation>Verkeerde gebruikersnaam of wachtwoord</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Login endpoint was not found on the server</source>
        <translation>Het inlog-endpoint is niet aangetroffen op de server</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>An unknown error occured. Please try again.</source>
        <translation>Er is een onbekende fout opgetreden. Probeer het opnieuw.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Malformed response. Possibly not a Matrix server</source>
        <translation>Onjuist antwoord ontvangen: dit is mogelijk geen Matrix server</translation>
    </message>
</context>
<context>
    <name>MemberList</name>
    <message>
        <location filename="../../src/dialogs/MemberList.cpp" line="+79"/>
        <source>Room members</source>
        <translation>Kamerleden</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>SHOW MORE</source>
        <translation>MEER TONEN</translation>
    </message>
</context>
<context>
    <name>QuickSwitcher</name>
    <message>
        <location filename="../../src/QuickSwitcher.cc" line="+70"/>
        <source>Search for a room...</source>
        <translation>Zoek een kamer...</translation>
    </message>
</context>
<context>
    <name>RegisterPage</name>
    <message>
        <location filename="../../src/RegisterPage.cc" line="+76"/>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Password confirmation</source>
        <translation>Wachtwoord bevestigen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Home Server</source>
        <translation>Thuisserver</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>REGISTER</source>
        <translation>REGISTREREN</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Invalid username</source>
        <translation>Ongeldige gebruikersnaam</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Password is not long enough (min 8 chars)</source>
        <translation>Het wachtwoord is niet lang genoeg (minimaal 8 tekens)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Passwords don&apos;t match</source>
        <translation>De wachtwoorden komen niet overeen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Invalid server name</source>
        <translation>Ongeldige servernaam</translation>
    </message>
</context>
<context>
    <name>RoomInfoListItem</name>
    <message>
        <location filename="../../src/RoomInfoListItem.cc" line="+78"/>
        <source>Leave room</source>
        <translation>Kamer verlaten</translation>
    </message>
    <message>
        <location line="+153"/>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decline</source>
        <translation>Afwijzen</translation>
    </message>
</context>
<context>
    <name>SideBarActions</name>
    <message>
        <location filename="../../src/SideBarActions.cc" line="+36"/>
        <source>Create new room</source>
        <translation>Nieuwe kamer creëren</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Join a room</source>
        <translation>Kamer betreden</translation>
    </message>
</context>
<context>
    <name>TextInputWidget</name>
    <message>
        <location filename="../../src/TextInputWidget.cc" line="+445"/>
        <source>Write a message...</source>
        <translation>Typ een bericht...</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>Select a file</source>
        <translation>Kies een bestand</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>TopRoomBar</name>
    <message>
        <location filename="../../src/TopRoomBar.cc" line="+87"/>
        <source>Invite users</source>
        <translation>Gebruikers uitnodigen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Members</source>
        <translation>Leden</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Leave room</source>
        <translation>Kamer verlaten</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../src/TrayIcon.cc" line="+116"/>
        <source>Show</source>
        <translation>Tonen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>TypingDisplay</name>
    <message>
        <location filename="../../src/TypingDisplay.cc" line="+26"/>
        <source> is typing</source>
        <translation> is aan het typen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source> are typing</source>
        <translation> zijn aan het typen</translation>
    </message>
</context>
<context>
    <name>UserSettingsPage</name>
    <message>
        <location filename="../../src/UserSettingsPage.cc" line="+121"/>
        <source>User Settings</source>
        <translation>Gebruikersinstellingen</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Minimize to tray</source>
        <translation>Minimaliseren naar systeemvak</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Start in tray</source>
        <translation>Geminimaliseerd opstarten</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Re-order rooms based on activity</source>
        <translation>Kamers herordenen op basis van activiteit</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Group&apos;s sidebar</source>
        <translation>Zijbalk van groep</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Typing notifications</source>
        <translation>Meldingen bij typen van berichten</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Read receipts</source>
        <translation>Leesbevestigingen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>GENERAL</source>
        <translation>ALGEMEEN</translation>
    </message>
</context>
<context>
    <name>WelcomePage</name>
    <message>
        <location filename="../../src/WelcomePage.cc" line="+44"/>
        <source>Welcome to nheko! The desktop client for the Matrix protocol.</source>
        <translation>Welkom bij nheko! Dé computerclient voor het Matrix-protocol.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enjoy your stay!</source>
        <translation>Geniet van je verblijf!</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>REGISTER</source>
        <translation>REGISTREREN</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>LOGIN</source>
        <translation>INLOGGEN</translation>
    </message>
</context>
<context>
    <name>dialogs::CreateRoom</name>
    <message>
        <location filename="../../src/dialogs/CreateRoom.cc" line="+32"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Topic</source>
        <translation>Onderwerp</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Room Visibility</source>
        <translation>Kamerzichtbaarheid</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Room Preset</source>
        <translation>Kamer-voorinstellingen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Direct Chat</source>
        <translation>Directe chat</translation>
    </message>
</context>
<context>
    <name>dialogs::InviteUsers</name>
    <message>
        <location filename="../../src/dialogs/InviteUsers.cc" line="+36"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>User ID to invite</source>
        <translation>Uit te nodigen gebruikers-id</translation>
    </message>
</context>
<context>
    <name>dialogs::JoinRoom</name>
    <message>
        <location filename="../../src/dialogs/JoinRoom.cc" line="+30"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Room ID or alias</source>
        <translation>Kamer-id of alias</translation>
    </message>
</context>
<context>
    <name>dialogs::LeaveRoom</name>
    <message>
        <location filename="../../src/dialogs/LeaveRoom.cc" line="+29"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Are you sure you want to leave?</source>
        <translation>Weet je zeker dat je wilt vertrekken?</translation>
    </message>
</context>
<context>
    <name>dialogs::Logout</name>
    <message>
        <location filename="../../src/dialogs/Logout.cc" line="+47"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Logout. Are you sure?</source>
        <translation>Uitloggen. Weet je het zeker?</translation>
    </message>
</context>
<context>
    <name>dialogs::PreviewUploadOverlay</name>
    <message>
        <location filename="../../src/dialogs/PreviewUploadOverlay.cc" line="+41"/>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Media type: %1
Media size: %2
</source>
        <translation>Mediasoort: %1
Mediagrootte: %2
</translation>
    </message>
</context>
<context>
    <name>dialogs::ReCaptcha</name>
    <message>
        <location filename="../../src/dialogs/ReCaptcha.cpp" line="+34"/>
        <source>CONFIRM</source>
        <translation>BEVESTIGEN</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Solve the reCAPTCHA and press the confirm button</source>
        <translation>Los de reCAPTCHA op en klik op &apos;Bevestigen&apos;</translation>
    </message>
</context>
<context>
    <name>dialogs::ReadReceipts</name>
    <message>
        <location filename="../../src/dialogs/ReadReceipts.cc" line="+98"/>
        <source>Read receipts</source>
        <translation>Leesbevestigingen</translation>
    </message>
</context>
<context>
    <name>dialogs::RoomSettings</name>
    <message>
        <location filename="../../src/dialogs/RoomSettings.cpp" line="+147"/>
        <source>CANCEL</source>
        <translation>ANNULEREN</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Notifications</source>
        <translation>Meldingen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Muted</source>
        <translation>Gedempt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mentions only</source>
        <translation>Alleen vermeldingen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All messages</source>
        <translation>Alle berichten</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Room access</source>
        <translation>Kamertoegang</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Anyone and guests</source>
        <translation>Iedereen, incl. gasten</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Anyone</source>
        <translation>Iedereen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Invited users</source>
        <translation>Uitgenodigde gebruikers</translation>
    </message>
</context>
<context>
    <name>emoji::Panel</name>
    <message>
        <location filename="../../src/emoji/Panel.cc" line="+125"/>
        <source>Smileys &amp; People</source>
        <translation>Smileys en mensen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Animals &amp; Nature</source>
        <translation>Dieren en natuur</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Food &amp; Drink</source>
        <translation>Eten en drinken</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Activity</source>
        <translation>Activiteit</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Travel &amp; Places</source>
        <translation>Reizen en locaties</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Objects</source>
        <translation>Objecten</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Symbols</source>
        <translation>Symbolen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flags</source>
        <translation>Vlaggen</translation>
    </message>
</context>
</TS>
